@@ -1,6 +1,6 @@
 /* ide-build-stage-mkdirs.c
  *
- * Copyright © 2016 Christian Hergert <chergert@redhat.com>
+ * Copyright 2016 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "ide-build-stage-mkdirs"
 
+#include "config.h"
+
 #include <glib.h>
 #include <glib/gprintf.h>
 #include <glib/gstdio.h>
@@ -50,7 +52,7 @@ clear_path (gpointer data)
 {
   Path *p = data;
 
-  g_clear_pointer (&p->path, g_free);
+  dzl_clear_pointer (&p->path, g_free);
 }
 
 static void
@@ -163,7 +165,7 @@ ide_build_stage_mkdirs_finalize (GObject *object)
   IdeBuildStageMkdirs *self = (IdeBuildStageMkdirs *)object;
   IdeBuildStageMkdirsPrivate *priv = ide_build_stage_mkdirs_get_instance_private (self);
 
-  g_clear_pointer (&priv->paths, g_array_unref);
+  dzl_clear_pointer (&priv->paths, g_array_unref);
 
   G_OBJECT_CLASS (ide_build_stage_mkdirs_parent_class)->finalize (object);
 }
