@@ -26,6 +26,7 @@
 
 #include "buildsystem/ide-build-pipeline.h"
 #include "buildsystem/ide-build-stage.h"
+#include "buildsystem/ide-build-stage-private.h"
 #include "subprocess/ide-subprocess.h"
 #include "threading/ide-task.h"
 
@@ -257,8 +258,8 @@ ide_build_stage_finalize (GObject *object)
 
   ide_build_stage_clear_observer (self);
 
-  g_clear_pointer (&priv->name, g_free);
-  g_clear_pointer (&priv->stdout_path, g_free);
+  dzl_clear_pointer (&priv->name, g_free);
+  dzl_clear_pointer (&priv->stdout_path, g_free);
   g_clear_object (&priv->queued_execute);
   g_clear_object (&priv->stdout_stream);
 
@@ -516,7 +517,6 @@ ide_build_stage_execute_async (IdeBuildStage       *self,
                                gpointer             user_data)
 {
   IdeBuildStagePrivate *priv = ide_build_stage_get_instance_private (self);
-  g_autoptr(IdeTask) task = NULL;
 
   g_return_if_fail (IDE_IS_BUILD_STAGE (self));
   g_return_if_fail (IDE_IS_BUILD_PIPELINE (pipeline));
@@ -541,7 +541,7 @@ ide_build_stage_execute_async (IdeBuildStage       *self,
 
       g_clear_object (&priv->stdout_stream);
 
-      priv->stdout_stream = g_steal_pointer (&stream);
+      priv->stdout_stream = G_OUTPUT_STREAM (g_steal_pointer (&stream));
     }
 
   IDE_BUILD_STAGE_GET_CLASS (self)->execute_async (self, pipeline, cancellable, callback, user_data);
