@@ -1,6 +1,6 @@
 /* ide-build-target.c
  *
- * Copyright © 2016 Christian Hergert <chergert@redhat.com>
+ * Copyright 2016 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,10 @@
 
 #define G_LOG_DOMAIN "ide-build-target"
 
+#include "config.h"
+
+#include <dazzle.h>
+
 #include "buildsystem/ide-build-target.h"
 
 G_DEFINE_INTERFACE (IdeBuildTarget, ide_build_target, IDE_TYPE_OBJECT)
@@ -130,7 +134,7 @@ ide_build_target_get_argv (IdeBuildTarget *self)
       g_autofree gchar *name = ide_build_target_get_name (self);
       g_autoptr(GFile) dir = ide_build_target_get_install_directory (self);
 
-      g_clear_pointer (&argv, g_strfreev);
+      dzl_clear_pointer (&argv, g_strfreev);
 
       if (!g_path_is_absolute (name) && dir != NULL && g_file_is_native (dir))
         {
