@@ -1,6 +1,6 @@
 /* ide-debugger-breakpoints.c
  *
- * Copyright © 2017 Christian Hergert <chergert@redhat.com>
+ * Copyright 2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,9 @@
 
 #define G_LOG_DOMAIN "ide-debugger-breakpoints"
 
+#include "config.h"
+
+#include <dazzle.h>
 #include <stdlib.h>
 
 #include "ide-debug.h"
@@ -99,7 +102,7 @@ ide_debugger_breakpoints_dispose (GObject *object)
 {
   IdeDebuggerBreakpoints *self = (IdeDebuggerBreakpoints *)object;
 
-  g_clear_pointer (&self->lines, g_array_unref);
+  dzl_clear_pointer (&self->lines, g_array_unref);
 
   G_OBJECT_CLASS (ide_debugger_breakpoints_parent_class)->dispose (object);
 }
