@@ -1,6 +1,6 @@
 /* ide-debugger-library.c
  *
- * Copyright © 2017 Christian Hergert <chergert@redhat.com>
+ * Copyright 2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,10 @@
 
 #define G_LOG_DOMAIN "ide-debugger-library"
 
+#include "config.h"
+
+#include <dazzle.h>
+
 #include "debugger/ide-debugger-library.h"
 
 typedef struct
@@ -46,10 +50,10 @@ ide_debugger_library_finalize (GObject *object)
   IdeDebuggerLibrary *self = (IdeDebuggerLibrary *)object;
   IdeDebuggerLibraryPrivate *priv = ide_debugger_library_get_instance_private (self);
 
-  g_clear_pointer (&priv->id, g_free);
-  g_clear_pointer (&priv->host_name, g_free);
-  g_clear_pointer (&priv->ranges, g_ptr_array_unref);
-  g_clear_pointer (&priv->target_name, g_free);
+  dzl_clear_pointer (&priv->id, g_free);
+  dzl_clear_pointer (&priv->host_name, g_free);
+  dzl_clear_pointer (&priv->ranges, g_ptr_array_unref);
+  dzl_clear_pointer (&priv->target_name, g_free);
 
   G_OBJECT_CLASS (ide_debugger_library_parent_class)->finalize (object);
 }
