@@ -1,6 +1,6 @@
 /* ide-debugger.c
  *
- * Copyright © 2017 Christian Hergert <chergert@redhat.com>
+ * Copyright 2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,10 @@
 
 #define G_LOG_DOMAIN "ide-debugger"
 
+#include "config.h"
+
+#include <dazzle.h>
+
 #include "debugger/ide-debugger.h"
 #include "debugger/ide-debugger-address-map.h"
 #include "debugger/ide-debugger-private.h"
@@ -318,8 +322,8 @@ ide_debugger_finalize (GObject *object)
   IdeDebugger *self = (IdeDebugger *)object;
   IdeDebuggerPrivate *priv = ide_debugger_get_instance_private (self);
 
-  g_clear_pointer (&priv->map, ide_debugger_address_map_free);
-  g_clear_pointer (&priv->display_name, g_free);
+  dzl_clear_pointer (&priv->map, ide_debugger_address_map_free);
+  dzl_clear_pointer (&priv->display_name, g_free);
   g_clear_object (&priv->breakpoints);
   g_clear_object (&priv->threads);
   g_clear_object (&priv->thread_groups);
@@ -926,7 +930,7 @@ ide_debugger_move_finish (IdeDebugger   *self,
                           GError       **error)
 {
   g_return_val_if_fail (IDE_IS_DEBUGGER (self), FALSE);
-  g_return_val_if_fail (G_IS_TASK (result), FALSE);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), FALSE);
 
   return IDE_DEBUGGER_GET_CLASS (self)->move_finish (self, result, error);
 }
@@ -1588,7 +1592,7 @@ ide_debugger_list_frames_finish (IdeDebugger   *self,
                                  GError       **error)
 {
   g_return_val_if_fail (IDE_IS_DEBUGGER (self), NULL);
-  g_return_val_if_fail (G_IS_TASK (result), NULL);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), NULL);
 
   return IDE_DEBUGGER_GET_CLASS (self)->list_frames_finish (self, result, error);
 }
@@ -1787,7 +1791,7 @@ ide_debugger_list_locals_finish (IdeDebugger   *self,
                                  GError       **error)
 {
   g_return_val_if_fail (IDE_IS_DEBUGGER (self), NULL);
-  g_return_val_if_fail (G_IS_TASK (result), NULL);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), NULL);
 
   return IDE_DEBUGGER_GET_CLASS (self)->list_locals_finish (self, result, error);
 }
@@ -1846,7 +1850,7 @@ ide_debugger_list_params_finish (IdeDebugger   *self,
                                  GError       **error)
 {
   g_return_val_if_fail (IDE_IS_DEBUGGER (self), NULL);
-  g_return_val_if_fail (G_IS_TASK (result), NULL);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), NULL);
 
   return IDE_DEBUGGER_GET_CLASS (self)->list_params_finish (self, result, error);
 }
@@ -1893,7 +1897,7 @@ ide_debugger_list_registers_finish (IdeDebugger   *self,
                                     GError       **error)
 {
   g_return_val_if_fail (IDE_IS_DEBUGGER (self), NULL);
-  g_return_val_if_fail (G_IS_TASK (result), NULL);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), NULL);
 
   return IDE_DEBUGGER_GET_CLASS (self)->list_registers_finish (self, result, error);
 }
@@ -1943,7 +1947,7 @@ ide_debugger_disassemble_finish (IdeDebugger   *self,
                                  GError       **error)
 {
   g_return_val_if_fail (IDE_IS_DEBUGGER (self), NULL);
-  g_return_val_if_fail (G_IS_TASK (result), NULL);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), NULL);
 
   return IDE_DEBUGGER_GET_CLASS (self)->disassemble_finish (self, result, error);
 }
