@@ -1,6 +1,6 @@
 /* ide-device-provider.c
  *
- * Copyright © 2015 Christian Hergert <christian@hergert.me>
+ * Copyright 2015 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,10 @@
 
 #define G_LOG_DOMAIN "ide-device-provider"
 
+#include "config.h"
+
+#include <dazzle.h>
+
 #include "devices/ide-device-provider.h"
 
 typedef struct
@@ -96,7 +100,7 @@ ide_device_provider_dispose (GObject *object)
   IdeDeviceProvider *self = (IdeDeviceProvider *)object;
   IdeDeviceProviderPrivate *priv = ide_device_provider_get_instance_private (self);
 
-  g_clear_pointer (&priv->devices, g_ptr_array_unref);
+  dzl_clear_pointer (&priv->devices, g_ptr_array_unref);
 
   G_OBJECT_CLASS (ide_device_provider_parent_class)->dispose (object);
 }
