@@ -25,6 +25,7 @@
 #include "ide-context.h"
 #include "ide-debug.h"
 
+#include "application/ide-application.h"
 #include "buffers/ide-buffer.h"
 #include "buffers/ide-buffer-manager.h"
 #include "diagnostics/ide-diagnostic.h"
@@ -168,7 +169,7 @@ free_diagnostics (gpointer data)
 {
   IdeDiagnostics *diagnostics = data;
 
-  g_clear_pointer (&diagnostics, ide_diagnostics_unref);
+  dzl_clear_pointer (&diagnostics, ide_diagnostics_unref);
 }
 
 static void
@@ -179,7 +180,7 @@ ide_diagnostics_group_free (gpointer data)
   g_assert (group != NULL);
   g_assert (group->ref_count == 0);
 
-  g_clear_pointer (&group->diagnostics_by_provider, g_hash_table_unref);
+  dzl_clear_pointer (&group->diagnostics_by_provider, g_hash_table_unref);
   g_weak_ref_clear (&group->buffer_wr);
   g_clear_object (&group->adapter);
   g_clear_object (&group->file);
@@ -276,6 +277,7 @@ ide_diagnostics_group_add (IdeDiagnosticsGroup   *group,
 {
   IdeDiagnostics *diagnostics;
 
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (group != NULL);
   g_assert (IDE_IS_DIAGNOSTIC_PROVIDER (provider));
   g_assert (diagnostic != NULL);
@@ -311,6 +313,7 @@ ide_diagnostics_group_diagnose_cb (GObject      *object,
 
   IDE_ENTRY;
 
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (IDE_IS_DIAGNOSTIC_PROVIDER (provider));
   g_assert (G_IS_ASYNC_RESULT (result));
   g_assert (IDE_IS_DIAGNOSTICS_MANAGER (self));
@@ -338,7 +341,7 @@ ide_diagnostics_group_diagnose_cb (GObject      *object,
        * so it is probably related to disposal.
        */
       g_warning ("Failed to locate group, possibly disposed.");
-      return;
+      IDE_EXIT;
     }
 
   /*
@@ -546,7 +549,7 @@ ide_diagnostics_manager_finalize (GObject *object)
   IdeDiagnosticsManager *self = (IdeDiagnosticsManager *)object;
 
   dzl_clear_source (&self->queued_diagnose_source);
-  g_clear_pointer (&self->groups_by_file, g_hash_table_unref);
+  dzl_clear_pointer (&self->groups_by_file, g_hash_table_unref);
 
   G_OBJECT_CLASS (ide_diagnostics_manager_parent_class)->finalize (object);
 }
@@ -791,7 +794,7 @@ ide_diagnostics_manager_clear_by_provider (IdeDiagnosticsManager *self,
            * are other providers loaded for this group.
            */
           if (g_hash_table_size (group->diagnostics_by_provider) == 0)
-            g_clear_pointer (&group->diagnostics_by_provider, g_hash_table_unref);
+            dzl_clear_pointer (&group->diagnostics_by_provider, g_hash_table_unref);
 
           /*
            * TODO: If this provider is not part of this group, we can possibly
@@ -1104,7 +1107,7 @@ ide_diagnostics_manager_buffer_unloaded (IdeDiagnosticsManager *self,
    */
   if (group->diagnostics_by_provider != NULL &&
       g_hash_table_size (group->diagnostics_by_provider) == 0)
-    g_clear_pointer (&group->diagnostics_by_provider, g_hash_table_unref);
+    dzl_clear_pointer (&group->diagnostics_by_provider, g_hash_table_unref);
 
   g_signal_handlers_disconnect_by_func (buffer,
                                         G_CALLBACK (ide_diagnostics_manager_buffer_changed),
