@@ -130,3 +130,77 @@ ide_source_range_unref (IdeSourceRange *self)
       DZL_COUNTER_DEC (instances);
     }
 }
+
+/**
+ * ide_source_range_to_variant:
+ * @self: a #IdeSourceRange
+ *
+ * Creates a variant to represent the range.
+ *
+ * This function will never return a floating variant.
+ *
+ * Returns: (transfer full): a #GVariant
+ *
+ * Since: 3.30
+ */
+GVariant *
+ide_source_range_to_variant (const IdeSourceRange *self)
+{
+  GVariantDict dict;
+  g_autoptr(GVariant) begin = NULL;
+  g_autoptr(GVariant) end = NULL;
+
+  g_return_val_if_fail (self != NULL, NULL);
+
+  g_variant_dict_init (&dict, NULL);
+
+  if (self->begin)
+    {
+      begin = ide_source_location_to_variant (self->begin);
+      g_variant_dict_insert_value (&dict, "begin", begin);
+    }
+
+  if (self->end)
+    {
+      end = ide_source_location_to_variant (self->end);
+      g_variant_dict_insert_value (&dict, "end", end);
+    }
+
+  return g_variant_ref_sink (g_variant_dict_end (&dict));
+}
+
+IdeSourceRange *
+ide_source_range_new_from_variant (GVariant *variant)
+{
+  g_autoptr(GVariant) unboxed = NULL;
+  g_autoptr(GVariant) vbegin = NULL;
+  g_autoptr(GVariant) vend = NULL;
+  g_autoptr(IdeSourceLocation) begin = NULL;
+  g_autoptr(IdeSourceLocation) end = NULL;
+  IdeSourceRange *self = NULL;
+  GVariantDict dict;
+
+  if (variant == NULL)
+    return NULL;
+
+  if (g_variant_is_of_type (variant, G_VARIANT_TYPE_VARIANT))
+    variant = unboxed = g_variant_get_variant (variant);
+
+  g_variant_dict_init (&dict, variant);
+
+  if (!(vbegin = g_variant_dict_lookup_value (&dict, "begin", NULL)) ||
+      !(begin = ide_source_location_new_from_variant (vbegin)))
+    goto failure;
+
+  if (!(vend = g_variant_dict_lookup_value (&dict, "end", NULL)) ||
+      !(end = ide_source_location_new_from_variant (vend)))
+    goto failure;
+
+  self = ide_source_range_new (begin, end);
+
+  g_variant_dict_clear (&dict);
+
+failure:
+
+  return self;
+}
