@@ -1,6 +1,6 @@
 /* ide-documentation.h
  *
- * Copyright © 2017 Lucie Charvat <luci.charavt@gmail.com>
+ * Copyright 2017 Lucie Charvat <luci.charavt@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,14 +28,12 @@ G_BEGIN_DECLS
 
 #define IDE_TYPE_DOCUMENTATION (ide_documentation_get_type())
 
-G_DECLARE_FINAL_TYPE (IdeDocumentation,
-                      ide_documentation,
-                      IDE, DOCUMENTATION,
-                      IdeObject)
+IDE_AVAILABLE_IN_ALL
+G_DECLARE_FINAL_TYPE (IdeDocumentation, ide_documentation, IDE, DOCUMENTATION, IdeObject)
 
 IDE_AVAILABLE_IN_ALL
-IdeDocumentationInfo    *ide_documentation_get_info    (IdeDocumentation        *self,
-                                                        const gchar             *input,
-                                                        IdeDocumentationContext  context);
+IdeDocumentationInfo *ide_documentation_get_info (IdeDocumentation        *self,
+                                                  const gchar             *input,
+                                                  IdeDocumentationContext  context);
 
 G_END_DECLS
