@@ -62,9 +62,14 @@ G_BEGIN_DECLS
 #include "buildsystem/ide-environment-variable.h"
 #include "buildsystem/ide-environment.h"
 #include "buildsystem/ide-simple-build-target.h"
-#include "completion/ide-completion-item.h"
+#include "completion/ide-completion.h"
+#include "completion/ide-completion-context.h"
+#include "completion/ide-completion-list-box-row.h"
+#include "completion/ide-completion-list-box.h"
+#include "completion/ide-completion-overlay.h"
+#include "completion/ide-completion-proposal.h"
 #include "completion/ide-completion-provider.h"
-#include "completion/ide-completion-results.h"
+#include "completion/ide-completion-window.h"
 #include "config/ide-configuration.h"
 #include "config/ide-configuration-manager.h"
 #include "config/ide-configuration-provider.h"
@@ -114,7 +119,9 @@ G_BEGIN_DECLS
 #include "highlighting/ide-highlight-index.h"
 #include "highlighting/ide-highlighter.h"
 #include "langserv/ide-langserv-client.h"
+#include "langserv/ide-langserv-completion-item.h"
 #include "langserv/ide-langserv-completion-provider.h"
+#include "langserv/ide-langserv-completion-results.h"
 #include "langserv/ide-langserv-diagnostic-provider.h"
 #include "langserv/ide-langserv-rename-provider.h"
 #include "langserv/ide-langserv-symbol-resolver.h"
@@ -152,12 +159,11 @@ G_BEGIN_DECLS
 #include "search/ide-search-reducer.h"
 #include "search/ide-search-result.h"
 #include "search/ide-tagged-entry.h"
-#include "snippets/ide-source-snippet-chunk.h"
-#include "snippets/ide-source-snippet-context.h"
-#include "snippets/ide-source-snippet-parser.h"
-#include "snippets/ide-source-snippet.h"
-#include "snippets/ide-source-snippets-manager.h"
-#include "snippets/ide-source-snippets.h"
+#include "snippets/ide-snippet.h"
+#include "snippets/ide-snippet-chunk.h"
+#include "snippets/ide-snippet-context.h"
+#include "snippets/ide-snippet-parser.h"
+#include "snippets/ide-snippet-storage.h"
 #include "sourceview/ide-indenter.h"
 #include "sourceview/ide-language.h"
 #include "sourceview/ide-source-map.h"
