@@ -756,7 +756,7 @@ ide_layout_grid_finalize (GObject *object)
   g_assert (priv->focus_column.tail == NULL);
   g_assert (priv->focus_column.length == 0);
 
-  g_clear_pointer (&priv->stack_info, g_array_unref);
+  dzl_clear_pointer (&priv->stack_info, g_array_unref);
   g_clear_object (&priv->toplevel_signals);
 
   G_OBJECT_CLASS (ide_layout_grid_parent_class)->finalize (object);
@@ -896,7 +896,7 @@ ide_layout_grid_init (IdeLayoutGrid *self)
 {
   IdeLayoutGridPrivate *priv = ide_layout_grid_get_instance_private (self);
   static const GtkTargetEntry target_entries[] = {
-    { "text/uri-list", 0, 0 },
+    { (gchar *)"text/uri-list", 0, 0 },
   };
 
   gtk_drag_dest_set (GTK_WIDGET (self),
