@@ -1,6 +1,6 @@
 /* ide-local-device.h
  *
- * Copyright © 2015 Christian Hergert <christian@hergert.me>
+ * Copyright 2015 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,12 +26,14 @@ G_BEGIN_DECLS
 
 #define IDE_TYPE_LOCAL_DEVICE (ide_local_device_get_type())
 
+IDE_AVAILABLE_IN_ALL
 G_DECLARE_DERIVABLE_TYPE (IdeLocalDevice, ide_local_device, IDE, LOCAL_DEVICE, IdeDevice)
 
 struct _IdeLocalDeviceClass
 {
   IdeDeviceClass parent;
 
+  /*< private >*/
   gpointer _reserved[8];
 };
 
