@@ -1,6 +1,6 @@
 /* ide-extension-adapter.c
  *
- * Copyright © 2015 Christian Hergert <christian@hergert.me>
+ * Copyright 2015 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "ide-extension-adapter"
 
+#include "config.h"
+
 #include <dazzle.h>
 #include <glib/gi18n.h>
 
@@ -338,8 +340,8 @@ ide_extension_adapter_finalize (GObject *object)
   g_clear_object (&self->engine);
   g_clear_object (&self->settings);
   g_clear_object (&self->settings_signals);
-  g_clear_pointer (&self->key, g_free);
-  g_clear_pointer (&self->value, g_free);
+  dzl_clear_pointer (&self->key, g_free);
+  dzl_clear_pointer (&self->value, g_free);
 
   G_OBJECT_CLASS (ide_extension_adapter_parent_class)->finalize (object);
 }
