@@ -41,6 +41,12 @@ enum {
 
 static GParamSpec *properties [LAST_PROP];
 
+/**
+ * ide_project_item_new:
+ * @parent: (nullable): an #IdeProjectItem
+ *
+ * Returns: (transfer full): an #IdeProjectItem
+ */
 IdeProjectItem *
 ide_project_item_new (IdeProjectItem *parent)
 {
@@ -129,7 +135,7 @@ ide_project_item_get_parent (IdeProjectItem *item)
   return priv->parent;
 }
 
-void
+static void
 ide_project_item_set_parent (IdeProjectItem *item,
                              IdeProjectItem *parent)
 {
@@ -149,7 +155,7 @@ ide_project_item_finalize (GObject *object)
   IdeProjectItemPrivate *priv = ide_project_item_get_instance_private (self);
 
   dzl_clear_weak_pointer (&priv->parent);
-  g_clear_pointer (&priv->children, g_sequence_free);
+  dzl_clear_pointer (&priv->children, g_sequence_free);
 
   G_OBJECT_CLASS (ide_project_item_parent_class)->finalize (object);
 }
