@@ -210,7 +210,7 @@ ide_project_finalize (GObject *object)
   IdeProject *self = (IdeProject *)object;
 
   g_clear_object (&self->root);
-  g_clear_pointer (&self->name, g_free);
+  dzl_clear_pointer (&self->name, g_free);
   g_rw_lock_clear (&self->rw_lock);
 
   G_OBJECT_CLASS (ide_project_parent_class)->finalize (object);
@@ -492,6 +492,7 @@ ide_project_rename_file_async (IdeProject          *self,
 
   task = ide_task_new (self, cancellable, callback, user_data);
   ide_task_set_source_tag (task, ide_project_rename_file_async);
+  ide_task_set_release_on_propagate (task, FALSE);
   ide_task_set_priority (task, G_PRIORITY_LOW);
 
   context = ide_object_get_context (IDE_OBJECT (self));
