@@ -74,7 +74,7 @@ request_destroy (Request *r)
 {
   g_assert (r->outstanding == 0);
   g_clear_object (&r->store);
-  g_clear_pointer (&r->query, g_free);
+  dzl_clear_pointer (&r->query, g_free);
   r->task = NULL;
   g_slice_free (Request, r);
 }
@@ -257,7 +257,6 @@ ide_search_engine_search_async (IdeSearchEngine     *self,
                                 gpointer             user_data)
 {
   g_autoptr(IdeTask) task = NULL;
-  g_autoptr(GListStore) store = NULL;
   Request *r;
 
   g_return_if_fail (IDE_IS_SEARCH_ENGINE (self));
