@@ -930,7 +930,6 @@ static gboolean
 sigterm_handler (gpointer user_data)
 {
   IdeBreakoutSubprocess *self = user_data;
-  g_autoptr(GDBusConnection) bus = NULL;
 
   IDE_ENTRY;
 
@@ -955,7 +954,6 @@ static gboolean
 sigint_handler (gpointer user_data)
 {
   IdeBreakoutSubprocess *self = user_data;
-  g_autoptr(GDBusConnection) bus = NULL;
 
   IDE_ENTRY;
 
@@ -1030,16 +1028,6 @@ maybe_create_output_stream (GOutputStream **ret,
   *fdptr = -1;
 }
 
-static inline void
-set_error_from_errno (GError **error)
-{
-  g_set_error (error,
-               G_IO_ERROR,
-               g_io_error_from_errno (errno),
-               "%s",
-               g_strerror (errno));
-}
-
 static void
 ide_breakout_subprocess_complete_command_locked (IdeBreakoutSubprocess *self,
                                                  gint                   exit_status)
@@ -1059,7 +1047,7 @@ ide_breakout_subprocess_complete_command_locked (IdeBreakoutSubprocess *self,
    * after the process has exited.
    */
   self->client_pid = 0;
-  g_clear_pointer (&self->identifier, g_free);
+  dzl_clear_pointer (&self->identifier, g_free);
 
   /* Remove our sources used for signal propagation */
   dzl_clear_source (&self->sigint_id);
@@ -1396,7 +1384,7 @@ ide_breakout_subprocess_initable_init (GInitable     *initable,
    * We don't want to allow these FDs to be used again.
    */
   self->fd_mapping_len = 0;
-  g_clear_pointer (&self->fd_mapping, g_free);
+  dzl_clear_pointer (&self->fd_mapping, g_free);
 
 
   /*
@@ -1597,11 +1585,11 @@ ide_breakout_subprocess_finalize (GObject *object)
   g_assert_cmpint (self->sigterm_id, ==, 0);
   g_assert_cmpint (self->exited_subscription, ==, 0);
 
-  g_clear_pointer (&self->identifier, g_free);
-  g_clear_pointer (&self->cwd, g_free);
-  g_clear_pointer (&self->argv, g_strfreev);
-  g_clear_pointer (&self->env, g_strfreev);
-  g_clear_pointer (&self->main_context, g_main_context_unref);
+  dzl_clear_pointer (&self->identifier, g_free);
+  dzl_clear_pointer (&self->cwd, g_free);
+  dzl_clear_pointer (&self->argv, g_strfreev);
+  dzl_clear_pointer (&self->env, g_strfreev);
+  dzl_clear_pointer (&self->main_context, g_main_context_unref);
 
   g_clear_object (&self->stdin_pipe);
   g_clear_object (&self->stdout_pipe);
@@ -1622,7 +1610,7 @@ ide_breakout_subprocess_finalize (GObject *object)
 
   for (guint i = 0; i < self->fd_mapping_len; i++)
     close (self->fd_mapping[i].source_fd);
-  g_clear_pointer (&self->fd_mapping, g_free);
+  dzl_clear_pointer (&self->fd_mapping, g_free);
 
   G_OBJECT_CLASS (ide_breakout_subprocess_parent_class)->finalize (object);
 
@@ -1790,5 +1778,5 @@ _ide_breakout_subprocess_new (const gchar                 *cwd,
   if (!g_initable_init (G_INITABLE (ret), cancellable, error))
     return NULL;
 
-  return g_steal_pointer (&ret);
+  return IDE_SUBPROCESS (g_steal_pointer (&ret));
 }
