@@ -20,6 +20,8 @@
 
 #include "config.h"
 
+#include <dazzle.h>
+
 #include "symbols/ide-code-index-entry.h"
 
 /**
@@ -66,8 +68,8 @@ ide_code_index_entry_free (IdeCodeIndexEntry *self)
 {
   if (self != NULL)
     {
-      g_clear_pointer (&self->name, g_free);
-      g_clear_pointer (&self->key, g_free);
+      dzl_clear_pointer (&self->name, g_free);
+      dzl_clear_pointer (&self->key, g_free);
       g_slice_free (IdeCodeIndexEntry, self);
     }
 }
@@ -127,7 +129,7 @@ ide_code_index_entry_get_flags (const IdeCodeIndexEntry *self)
  * @end_line: (out): last line
  * @end_line_offset: (out): last line offset
  *
- * Since: 3.28.2
+ * Since: 3.30
  */
 void
 ide_code_index_entry_get_range (const IdeCodeIndexEntry *self,
@@ -162,8 +164,8 @@ ide_code_index_entry_builder_free (IdeCodeIndexEntryBuilder *builder)
 {
   if (builder != NULL)
     {
-      g_clear_pointer (&builder->entry.key, g_free);
-      g_clear_pointer (&builder->entry.name, g_free);
+      dzl_clear_pointer (&builder->entry.key, g_free);
+      dzl_clear_pointer (&builder->entry.name, g_free);
       g_slice_free (IdeCodeIndexEntryBuilder, builder);
     }
 }
@@ -235,7 +237,7 @@ ide_code_index_entry_builder_set_kind (IdeCodeIndexEntryBuilder *builder,
  *
  * Returns: (transfer full): an #IdeCodeIndexEntry
  *
- * Since: 3.28.2
+ * Since: 3.30
  */
 IdeCodeIndexEntry *
 ide_code_index_entry_builder_build (IdeCodeIndexEntryBuilder *builder)
@@ -251,7 +253,7 @@ ide_code_index_entry_builder_build (IdeCodeIndexEntryBuilder *builder)
  *
  * Returns: (transfer full): a deep copy of @builder
  *
- * Since: 3.28.2
+ * Since: 3.30
  */
 IdeCodeIndexEntryBuilder *
 ide_code_index_entry_builder_copy (IdeCodeIndexEntryBuilder *builder)
