@@ -1,6 +1,6 @@
 /* ide-terminal-search.c
  *
- * Copyright © 2015 Christian Hergert <christian@hergert.me>
+ * Copyright 2015 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -125,7 +125,7 @@ update_regex (IdeTerminalSearch *self)
       vte_regex_unref (self->regex);
     }
 
-  g_clear_pointer (&self->regex_pattern, g_free);
+  dzl_clear_pointer (&self->regex_pattern, g_free);
 
   if (search_text[0] != '\0')
     {
