@@ -36,6 +36,7 @@
 #include "toolchain/ide-simple-toolchain.h"
 #include "toolchain/ide-toolchain.h"
 #include "toolchain/ide-toolchain-manager.h"
+#include "toolchain/ide-toolchain-private.h"
 #include "toolchain/ide-toolchain-provider.h"
 
 struct _IdeToolchainManager
@@ -65,7 +66,7 @@ static void
 prepare_state_free (PrepareState *state)
 {
   g_clear_object (&state->pipeline);
-  g_clear_pointer (&state->toolchain_id, g_free);
+  dzl_clear_pointer (&state->toolchain_id, g_free);
   g_slice_free (PrepareState, state);
 }
 
@@ -382,7 +383,7 @@ ide_toolchain_manager_dispose (GObject *object)
   IdeToolchainManager *self = (IdeToolchainManager *)object;
 
   g_clear_object (&self->extensions);
-  g_clear_pointer (&self->toolchains, g_ptr_array_unref);
+  dzl_clear_pointer (&self->toolchains, g_ptr_array_unref);
   g_clear_object (&self->cancellable);
 
   G_OBJECT_CLASS (ide_toolchain_manager_parent_class)->dispose (object);
