@@ -1,6 +1,6 @@
 /* ide-autotools-autogen-stage.c
  *
- * Copyright © 2016 Christian Hergert <chergert@redhat.com>
+ * Copyright 2016 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,16 +43,16 @@ ide_autotools_autogen_stage_wait_check_cb (GObject      *object,
                                            gpointer      user_data)
 {
   IdeSubprocess *subprocess = (IdeSubprocess *)object;
-  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeTask) task = user_data;
   g_autoptr(GError) error = NULL;
 
   g_assert (IDE_IS_SUBPROCESS (subprocess));
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
 
   if (!ide_subprocess_wait_check_finish (subprocess, result, &error))
-    g_task_return_error (task, g_steal_pointer (&error));
+    ide_task_return_error (task, g_steal_pointer (&error));
   else
-    g_task_return_boolean (task, TRUE);
+    ide_task_return_boolean (task, TRUE);
 }
 
 static void
@@ -66,14 +66,14 @@ ide_autotools_autogen_stage_execute_async (IdeBuildStage       *stage,
   g_autofree gchar *autogen_path = NULL;
   g_autoptr(IdeSubprocessLauncher) launcher = NULL;
   g_autoptr(IdeSubprocess) subprocess = NULL;
-  g_autoptr(GTask) task = NULL;
+  g_autoptr(IdeTask) task = NULL;
   g_autoptr(GError) error = NULL;
 
   g_assert (IDE_IS_AUTOTOOLS_AUTOGEN_STAGE (self));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
-  task = g_task_new (self, cancellable, callback, user_data);
-  g_task_set_source_tag (task, ide_autotools_autogen_stage_execute_async);
+  task = ide_task_new (self, cancellable, callback, user_data);
+  ide_task_set_source_tag (task, ide_autotools_autogen_stage_execute_async);
 
   autogen_path = g_build_filename (self->srcdir, "autogen.sh", NULL);
 
@@ -81,7 +81,7 @@ ide_autotools_autogen_stage_execute_async (IdeBuildStage       *stage,
 
   if (launcher == NULL)
     {
-      g_task_return_error (task, g_steal_pointer (&error));
+      ide_task_return_error (task, g_steal_pointer (&error));
       return;
     }
 
@@ -102,7 +102,7 @@ ide_autotools_autogen_stage_execute_async (IdeBuildStage       *stage,
 
   if (subprocess == NULL)
     {
-      g_task_return_error (task, g_steal_pointer (&error));
+      ide_task_return_error (task, g_steal_pointer (&error));
       return;
     }
 
@@ -120,9 +120,9 @@ ide_autotools_autogen_stage_execute_finish (IdeBuildStage  *stage,
                                             GError        **error)
 {
   g_assert (IDE_IS_AUTOTOOLS_AUTOGEN_STAGE (stage));
-  g_assert (G_IS_TASK (result));
+  g_assert (IDE_IS_TASK (result));
 
-  return g_task_propagate_boolean (G_TASK (result), error);
+  return ide_task_propagate_boolean (IDE_TASK (result), error);
 }
 
 static void
@@ -130,7 +130,7 @@ ide_autotools_autogen_stage_finalize (GObject *object)
 {
   IdeAutotoolsAutogenStage *self = (IdeAutotoolsAutogenStage *)object;
 
-  g_clear_pointer (&self->srcdir, g_free);
+  dzl_clear_pointer (&self->srcdir, g_free);
 
   G_OBJECT_CLASS (ide_autotools_autogen_stage_parent_class)->finalize (object);
 }
