@@ -79,8 +79,8 @@ file_flags_lookup_free (gpointer data)
 
   g_clear_object (&lookup->self);
   g_clear_object (&lookup->file);
-  g_clear_pointer (&lookup->targets, g_ptr_array_unref);
-  g_clear_pointer (&lookup->relative_path, g_free);
+  dzl_clear_pointer (&lookup->targets, g_ptr_array_unref);
+  dzl_clear_pointer (&lookup->relative_path, g_free);
   g_slice_free (FileFlagsLookup, lookup);
 }
 
@@ -89,8 +89,8 @@ file_targets_lookup_free (gpointer data)
 {
   FileTargetsLookup *lookup = data;
 
-  g_clear_pointer (&lookup->path, g_free);
-  g_clear_pointer (&lookup->mapped, g_mapped_file_unref);
+  dzl_clear_pointer (&lookup->path, g_free);
+  dzl_clear_pointer (&lookup->mapped, g_mapped_file_unref);
   g_slice_free (FileTargetsLookup, lookup);
 }
 
@@ -660,18 +660,18 @@ ide_makecache_get_file_flags_worker (GTask        *task,
 
       argv = g_ptr_array_new ();
       g_ptr_array_add (argv, (gchar *)lookup->self->make_name);
-      g_ptr_array_add (argv, "-C");
+      g_ptr_array_add (argv, (gchar *)"-C");
       g_ptr_array_add (argv, (gchar *)(subdir ?: "."));
-      g_ptr_array_add (argv, "-s");
-      g_ptr_array_add (argv, "-i");
-      g_ptr_array_add (argv, "-n");
-      g_ptr_array_add (argv, "-W");
+      g_ptr_array_add (argv, (gchar *)"-s");
+      g_ptr_array_add (argv, (gchar *)"-i");
+      g_ptr_array_add (argv, (gchar *)"-n");
+      g_ptr_array_add (argv, (gchar *)"-W");
       g_ptr_array_add (argv, (gchar *)relpath);
       g_ptr_array_add (argv, (gchar *)targetstr);
-      g_ptr_array_add (argv, "V=1");
-      g_ptr_array_add (argv, "CC="FAKE_CC);
-      g_ptr_array_add (argv, "CXX="FAKE_CXX);
-      g_ptr_array_add (argv, "VALAC="FAKE_VALAC);
+      g_ptr_array_add (argv, (gchar *)"V=1");
+      g_ptr_array_add (argv, (gchar *)"CC="FAKE_CC);
+      g_ptr_array_add (argv, (gchar *)"CXX="FAKE_CXX);
+      g_ptr_array_add (argv, (gchar *)"VALAC="FAKE_VALAC);
       g_ptr_array_add (argv, NULL);
 
 #ifdef IDE_ENABLE_TRACE
@@ -1021,8 +1021,8 @@ ide_makecache_finalize (GObject *object)
   g_clear_object (&self->runtime);
   g_clear_object (&self->parent);
 
-  g_clear_pointer (&self->mapped, g_mapped_file_unref);
-  g_clear_pointer (&self->build_targets, g_ptr_array_unref);
+  dzl_clear_pointer (&self->mapped, g_mapped_file_unref);
+  dzl_clear_pointer (&self->build_targets, g_ptr_array_unref);
 
   G_OBJECT_CLASS (ide_makecache_parent_class)->finalize (object);
 
