@@ -69,9 +69,9 @@ call_free (gpointer data)
 
   c->cancel_id = 0;
 
-  g_clear_pointer (&c->method, g_free);
-  g_clear_pointer (&c->params, g_variant_unref);
-  g_clear_pointer (&c->id, g_variant_unref);
+  dzl_clear_pointer (&c->method, g_free);
+  dzl_clear_pointer (&c->params, g_variant_unref);
+  dzl_clear_pointer (&c->id, g_variant_unref);
   g_clear_object (&c->cancellable);
   g_clear_object (&c->self);
   g_slice_free (Call, c);
@@ -157,7 +157,7 @@ ide_clang_client_subprocess_exited (IdeClangClient          *self,
     self->state = STATE_SPAWNING;
 
   g_clear_object (&self->rpc_client);
-  g_clear_pointer (&self->seq_by_file, g_hash_table_unref);
+  dzl_clear_pointer (&self->seq_by_file, g_hash_table_unref);
 
   IDE_EXIT;
 }
@@ -344,6 +344,7 @@ ide_clang_client_constructed (GObject *object)
   if (cwd != NULL)
     ide_subprocess_launcher_set_cwd (launcher, cwd);
   ide_subprocess_launcher_set_clear_env (launcher, FALSE);
+  ide_subprocess_launcher_setenv (launcher, "DZL_COUNTER_DISABLE_SHM", "1", TRUE);
 #if 0
   ide_subprocess_launcher_push_argv (launcher, "gdbserver");
   ide_subprocess_launcher_push_argv (launcher, "localhost:8888");
@@ -417,7 +418,7 @@ ide_clang_client_finalize (GObject *object)
 {
   IdeClangClient *self = (IdeClangClient *)object;
 
-  g_clear_pointer (&self->seq_by_file, g_hash_table_unref);
+  dzl_clear_pointer (&self->seq_by_file, g_hash_table_unref);
   g_clear_object (&self->rpc_client);
   g_clear_object (&self->root_uri);
   g_clear_object (&self->supervisor);
@@ -506,7 +507,6 @@ static void
 ide_clang_client_call_cancelled (GCancellable *cancellable,
                                  Call         *call)
 {
-  g_autoptr(GVariant) params = NULL;
   GVariantDict dict;
 
   g_assert (G_IS_CANCELLABLE (cancellable));
@@ -548,7 +548,7 @@ ide_clang_client_call_async (IdeClangClient      *self,
   call = g_slice_new0 (Call);
   call->self = g_object_ref (self);
   call->method = g_strdup (method);
-  call->params = g_variant_ref_sink (params);
+  call->params = params ? g_variant_ref_sink (params) : NULL;
 
   task = ide_task_new (self, cancellable, callback, user_data);
   ide_task_set_source_tag (task, ide_clang_client_call_async);
