@@ -95,6 +95,7 @@ typedef struct
   IdePersistentMapBuilder *map_builder;
   DzlFuzzyIndexBuilder    *fuzzy_builder;
   guint32                  file_id;
+  guint                    has_called : 1;
 } AddEntriesData;
 
 enum {
@@ -118,22 +119,22 @@ build_data_free (BuildData *self)
   g_clear_object (&self->index_dir);
   g_clear_object (&self->building_data_dir);
   g_clear_object (&self->building_index_dir);
-  g_clear_pointer (&self->changes, g_ptr_array_unref);
+  dzl_clear_pointer (&self->changes, g_ptr_array_unref);
   g_slice_free (BuildData, self);
 }
 
 static void
 indexer_info_free (IndexerInfo *info)
 {
-  g_clear_pointer (&info->specs, g_ptr_array_unref);
-  g_clear_pointer (&info->mime_types, g_ptr_array_unref);
+  dzl_clear_pointer (&info->specs, g_ptr_array_unref);
+  dzl_clear_pointer (&info->mime_types, g_ptr_array_unref);
   g_slice_free (IndexerInfo, info);
 }
 
 static void
 get_changes_data_free (GetChangesData *self)
 {
-  g_clear_pointer (&self->indexers, indexer_info_free);
+  dzl_clear_pointer (&self->indexers, indexer_info_free);
   g_clear_object (&self->data_dir);
   g_clear_object (&self->index_dir);
   g_clear_object (&self->vcs);
@@ -154,7 +155,7 @@ add_entries_data_free (AddEntriesData *self)
 static void
 file_info_free (FileInfo *file_info)
 {
-  g_clear_pointer (&file_info->name, g_free);
+  dzl_clear_pointer (&file_info->name, g_free);
   g_clear_object (&file_info->directory);
   g_slice_free (FileInfo, file_info);
 }
@@ -949,14 +950,22 @@ add_entries_to_index_next_entries_cb (GObject      *object,
       return;
     }
 
-  if (ret == NULL || ret->len == 0)
+  g_assert (ret != NULL);
+
+  cancellable = ide_task_get_cancellable (task);
+  task_data = ide_task_get_task_data (task);
+
+  /*
+   * Make sure that we at least insert the result set once, but ignore the
+   * follow up call if it has 0 results.
+   */
+  if (ret->len == 0 && task_data->has_called)
     {
       ide_task_return_boolean (task, TRUE);
       return;
     }
 
-  cancellable = ide_task_get_cancellable (task);
-  task_data = ide_task_get_task_data (task);
+  task_data->has_called = TRUE;
 
   g_assert (task_data != NULL);
   g_assert (IDE_IS_CODE_INDEX_ENTRIES (task_data->entries));
@@ -972,10 +981,13 @@ add_entries_to_index_next_entries_cb (GObject      *object,
                         task_data->map_builder,
                         task_data->fuzzy_builder);
 
-  ide_code_index_entries_next_entries_async (entries,
-                                             cancellable,
-                                             add_entries_to_index_next_entries_cb,
-                                             g_steal_pointer (&task));
+  if (ret->len > 0)
+    ide_code_index_entries_next_entries_async (entries,
+                                               cancellable,
+                                               add_entries_to_index_next_entries_cb,
+                                               g_steal_pointer (&task));
+  else
+    ide_task_return_boolean (task, TRUE);
 }
 
 static void
