@@ -156,7 +156,6 @@ discover_groups (GbCommandGactionProvider *provider)
   GtkWidget *widget;
   GbGroup *gb_group = NULL;
   GList *list = NULL;
-  GType type;
 
   g_return_val_if_fail (GB_IS_COMMAND_GACTION_PROVIDER (provider), NULL);
 
@@ -174,11 +173,6 @@ discover_groups (GbCommandGactionProvider *provider)
       show_prefix_actions (G_OBJECT (widget));
 #endif
 
-      /* We exclude these types, they're already in the widgets hierarchy */
-      type = G_OBJECT_TYPE (widget);
-      if (type == IDE_TYPE_EDITOR_VIEW)
-        continue;
-
       prefixes = gtk_widget_list_action_prefixes (widget);
 
       if (prefixes)
@@ -262,8 +256,8 @@ parse_command_text (const gchar  *command_text,
   return TRUE;
 
 failure:
-  g_clear_pointer (&ret_name, g_free);
-  g_clear_pointer (&ret_params, g_variant_unref);
+  dzl_clear_pointer (&ret_name, g_free);
+  dzl_clear_pointer (&ret_params, g_variant_unref);
 
   return FALSE;
 }
@@ -407,7 +401,7 @@ gb_command_gaction_provider_lookup (GbCommandProvider *provider,
                               NULL);
     }
 
-  g_clear_pointer (&params, g_variant_unref);
+  dzl_clear_pointer (&params, g_variant_unref);
   g_free (command_name);
   g_list_free_full (gb_groups, (GDestroyNotify)gb_group_free);
 
