@@ -1,6 +1,6 @@
 /* gb-command-gaction.c
  *
- * Copyright © 2014 Christian Hergert <christian@hergert.me>
+ * Copyright 2014 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 
 #define G_LOG_DOMAIN "command-gaction"
 
+#include <dazzle.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
@@ -66,7 +67,7 @@ gb_command_gaction_set_action_name (GbCommandGaction *gaction,
 
   if (gaction->action_name != action_name)
     {
-      g_clear_pointer (&gaction->action_name, g_free);
+      dzl_clear_pointer (&gaction->action_name, g_free);
       gaction->action_name = g_strdup (action_name);
     }
 }
@@ -79,7 +80,7 @@ gb_command_gaction_set_parameters (GbCommandGaction *gaction,
 
   if (gaction->parameters != variant)
     {
-      g_clear_pointer (&gaction->parameters, g_variant_unref);
+      dzl_clear_pointer (&gaction->parameters, g_variant_unref);
       gaction->parameters = g_variant_ref (variant);
     }
 }
@@ -105,8 +106,8 @@ gb_command_gaction_finalize (GObject *object)
   GbCommandGaction *self = GB_COMMAND_GACTION (object);
 
   g_clear_object (&self->action_group);
-  g_clear_pointer (&self->action_name, g_free);
-  g_clear_pointer (&self->parameters, g_variant_unref);
+  dzl_clear_pointer (&self->action_name, g_free);
+  dzl_clear_pointer (&self->parameters, g_variant_unref);
 
   G_OBJECT_CLASS (gb_command_gaction_parent_class)->finalize (object);
 }
