@@ -38,17 +38,6 @@ gb_command_manager_new (void)
   return g_object_new (GB_TYPE_COMMAND_MANAGER, NULL);
 }
 
-GbCommandManager *
-gb_command_manager_get_default (void)
-{
-  static GbCommandManager *instance;
-
-  if (!instance)
-    instance = gb_command_manager_new ();
-
-  return instance;
-}
-
 static gint
 provider_compare_func (gconstpointer a,
                        gconstpointer b)
@@ -153,7 +142,7 @@ gb_command_manager_finalize (GObject *object)
 {
   GbCommandManager *self = GB_COMMAND_MANAGER (object);
 
-  g_clear_pointer (&self->providers, g_ptr_array_unref);
+  dzl_clear_pointer (&self->providers, g_ptr_array_unref);
 
   G_OBJECT_CLASS (gb_command_manager_parent_class)->finalize (object);
 }
