@@ -47,12 +47,11 @@ enum {
 
 static void symbol_resolver_iface_init (IdeSymbolResolverInterface *iface);
 
-G_DEFINE_DYNAMIC_TYPE_EXTENDED (IdeCtagsSymbolResolver,
-                                ide_ctags_symbol_resolver,
-                                IDE_TYPE_OBJECT,
-                                0,
-                                G_IMPLEMENT_INTERFACE (IDE_TYPE_SYMBOL_RESOLVER,
-                                                       symbol_resolver_iface_init))
+G_DEFINE_TYPE_WITH_CODE (IdeCtagsSymbolResolver,
+                         ide_ctags_symbol_resolver,
+                         IDE_TYPE_OBJECT,
+                         G_IMPLEMENT_INTERFACE (IDE_TYPE_SYMBOL_RESOLVER,
+                                                symbol_resolver_iface_init))
 
 static void
 lookup_symbol_free (gpointer data)
@@ -438,7 +437,7 @@ tree_resolver_state_free (gpointer data)
 
   if (state != NULL)
     {
-      g_clear_pointer (&state->indexes, g_ptr_array_unref);
+      dzl_clear_pointer (&state->indexes, g_ptr_array_unref);
       g_clear_object (&state->file);
       g_slice_free (TreeResolverState, state);
     }
@@ -718,11 +717,6 @@ ide_ctags_symbol_resolver_class_init (IdeCtagsSymbolResolverClass *klass)
 {
 }
 
-static void
-ide_ctags_symbol_resolver_class_finalize (IdeCtagsSymbolResolverClass *klass)
-{
-}
-
 static void
 ide_ctags_symbol_resolver_init (IdeCtagsSymbolResolver *resolver)
 {
@@ -737,12 +731,6 @@ symbol_resolver_iface_init (IdeSymbolResolverInterface *iface)
   iface->get_symbol_tree_finish = ide_ctags_symbol_resolver_get_symbol_tree_finish;
 }
 
-void
-_ide_ctags_symbol_resolver_register_type (GTypeModule *module)
-{
-  ide_ctags_symbol_resolver_register_type (module);
-}
-
 void
 ide_ctags_symbol_resolver_get_location_async (IdeCtagsSymbolResolver   *self,
                                               IdeCtagsIndex            *index,
