@@ -79,7 +79,7 @@ module_source_free (void *data)
 {
   ModuleSource *src = data;
 
-  g_clear_pointer (&src->uri, ide_vcs_uri_unref);
+  dzl_clear_pointer (&src->uri, ide_vcs_uri_unref);
   g_free (src->branch);
   g_free (src->sha);
   g_strfreev (src->patches);
@@ -150,10 +150,10 @@ gbp_flatpak_clone_widget_finalize (GObject *object)
 {
   GbpFlatpakCloneWidget *self = (GbpFlatpakCloneWidget *)object;
 
-  g_clear_pointer (&self->app_id_override, g_free);
-  g_clear_pointer (&self->child_name, g_free);
-  g_clear_pointer (&self->id, g_free);
-  g_clear_pointer (&self->manifest, g_free);
+  dzl_clear_pointer (&self->app_id_override, g_free);
+  dzl_clear_pointer (&self->child_name, g_free);
+  dzl_clear_pointer (&self->id, g_free);
+  dzl_clear_pointer (&self->manifest, g_free);
 
   G_OBJECT_CLASS (gbp_flatpak_clone_widget_parent_class)->finalize (object);
 }
@@ -355,7 +355,7 @@ gbp_flatpak_clone_widget_worker (IdeTask      *task,
           clone_options = ggit_clone_options_new ();
           ggit_clone_options_set_is_bare (clone_options, FALSE);
           ggit_clone_options_set_fetch_options (clone_options, fetch_options);
-          g_clear_pointer (&fetch_options, ggit_fetch_options_free);
+          dzl_clear_pointer (&fetch_options, ggit_fetch_options_free);
 
           uristr = ide_vcs_uri_to_string (req->src->uri);
           repository = ggit_repository_clone (uristr, req->destination, clone_options, &error);
@@ -391,12 +391,12 @@ gbp_flatpak_clone_widget_worker (IdeTask      *task,
   else if (req->src->type == TYPE_ARCHIVE)
     {
       uristr = ide_vcs_uri_to_string (req->src->uri);
-      req->project_file = fetch_archive (uristr,
-                                         req->src->sha,
-                                         req->src->name,
-                                         req->destination,
-                                         self->strip_components,
-                                         &error);
+      req->project_file = gbp_flatpak_sources_fetch_archive (uristr,
+                                                             req->src->sha,
+                                                             req->src->name,
+                                                             req->destination,
+                                                             self->strip_components,
+                                                             &error);
       if (error != NULL)
         {
           ide_task_return_error (task, g_steal_pointer (&error));
@@ -406,11 +406,11 @@ gbp_flatpak_clone_widget_worker (IdeTask      *task,
 
   for (i = 0; req->src->patches[i]; i++)
     {
-      if (!apply_patch (req->src->patches[i],
-                        req->project_file,
-                        self->strip_components,
-                        &error))
-        {
+      if (!gbp_flatpak_sources_apply_patch (req->src->patches[i],
+                                            req->project_file,
+                                            self->strip_components,
+                                            &error))
+      {
           ide_task_return_error (task, g_steal_pointer (&error));
           return;
         }
@@ -491,7 +491,6 @@ get_source (GbpFlatpakCloneWidget  *self,
   JsonArray *sources = NULL;
   guint num_modules;
   ModuleSource *src;
-  g_autoptr(IdeVcsUri) uri = NULL;
   GPtrArray *patches;
 
   parser = json_parser_new ();
@@ -576,7 +575,6 @@ gbp_flatpak_clone_widget_clone_async (GbpFlatpakCloneWidget   *self,
   g_autoptr(IdeTask) task = NULL;
   g_autoptr(GFile) destination = NULL;
   g_autoptr(GError) error = NULL;
-  g_autofree gchar *path = NULL;
   DownloadRequest *req;
   ModuleSource *src;
 
