@@ -222,8 +222,7 @@ discover_environ (GbpFlatpakManifest *self,
 
   env = ide_configuration_get_environment (IDE_CONFIGURATION (self));
 
-  if (json_object_has_member (build_options, "env") &&
-      (obj = json_object_get_object_member (build_options, "env")))
+  if ((obj = json_object_get_object_member (build_options, "env")))
     {
       JsonObjectIter iter;
       const gchar *key;
@@ -554,19 +553,19 @@ gbp_flatpak_manifest_finalize (GObject *object)
   g_clear_object (&self->file);
   g_clear_object (&self->file_monitor);
 
-  g_clear_pointer (&self->root, json_node_unref);
+  dzl_clear_pointer (&self->root, json_node_unref);
 
-  g_clear_pointer (&self->build_args, g_strfreev);
-  g_clear_pointer (&self->command, g_free);
-  g_clear_pointer (&self->finish_args, g_strfreev);
-  g_clear_pointer (&self->runtime, g_free);
-  g_clear_pointer (&self->runtime_version, g_free);
-  g_clear_pointer (&self->sdk, g_free);
-  g_clear_pointer (&self->sdk_extensions, g_strfreev);
+  dzl_clear_pointer (&self->build_args, g_strfreev);
+  dzl_clear_pointer (&self->command, g_free);
+  dzl_clear_pointer (&self->finish_args, g_strfreev);
+  dzl_clear_pointer (&self->runtime, g_free);
+  dzl_clear_pointer (&self->runtime_version, g_free);
+  dzl_clear_pointer (&self->sdk, g_free);
+  dzl_clear_pointer (&self->sdk_extensions, g_strfreev);
 
-  g_clear_pointer (&self->primary, json_object_unref);
-  g_clear_pointer (&self->primary_module, g_free);
-  g_clear_pointer (&self->config_opts, g_strfreev);
+  dzl_clear_pointer (&self->primary, json_object_unref);
+  dzl_clear_pointer (&self->primary_module, g_free);
+  dzl_clear_pointer (&self->config_opts, g_strfreev);
 
   G_OBJECT_CLASS (gbp_flatpak_manifest_parent_class)->finalize (object);
 }
