@@ -326,7 +326,7 @@ get_binary_name (GbpFlatpakRuntime *self,
   }
 }
 
-IdeRunner *
+static IdeRunner *
 gbp_flatpak_runtime_create_runner (IdeRuntime     *runtime,
                                    IdeBuildTarget *build_target)
 {
@@ -514,7 +514,7 @@ gbp_flatpak_runtime_get_triplet (GbpFlatpakRuntime *self)
   return self->triplet;
 }
 
-void
+static void
 gbp_flatpak_runtime_set_triplet (GbpFlatpakRuntime *self,
                                  IdeTriplet        *triplet)
 {
@@ -522,7 +522,7 @@ gbp_flatpak_runtime_set_triplet (GbpFlatpakRuntime *self,
 
   if (self->triplet != triplet)
     {
-      g_clear_pointer (&self->triplet, ide_triplet_unref);
+      dzl_clear_pointer (&self->triplet, ide_triplet_unref);
       self->triplet = ide_triplet_ref (triplet);
       g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_TRIPLET]);
     }
@@ -536,7 +536,7 @@ gbp_flatpak_runtime_get_branch (GbpFlatpakRuntime *self)
   return self->branch;
 }
 
-void
+static void
 gbp_flatpak_runtime_set_branch (GbpFlatpakRuntime *self,
                                 const gchar       *branch)
 {
@@ -558,7 +558,7 @@ gbp_flatpak_runtime_get_platform (GbpFlatpakRuntime *self)
   return self->platform;
 }
 
-void
+static void
 gbp_flatpak_runtime_set_platform (GbpFlatpakRuntime *self,
                                   const gchar       *platform)
 {
@@ -595,7 +595,7 @@ gbp_flatpak_runtime_get_sdk_name (GbpFlatpakRuntime *self)
     return g_strndup (self->sdk, slash - self->sdk);
 }
 
-void
+static void
 gbp_flatpak_runtime_set_sdk (GbpFlatpakRuntime *self,
                              const gchar       *sdk)
 {
@@ -622,7 +622,7 @@ gbp_flatpak_runtime_real_get_triplet (IdeRuntime *runtime)
   return ide_triplet_ref (GBP_FLATPAK_RUNTIME (runtime)->triplet);
 }
 
-gboolean
+static gboolean
 gbp_flatpak_runtime_supports_toolchain (IdeRuntime   *self,
                                         IdeToolchain *toolchain)
 {
@@ -704,13 +704,13 @@ gbp_flatpak_runtime_finalize (GObject *object)
 {
   GbpFlatpakRuntime *self = (GbpFlatpakRuntime *)object;
 
-  g_clear_pointer (&self->triplet, ide_triplet_unref);
-  g_clear_pointer (&self->branch, g_free);
-  g_clear_pointer (&self->runtime_dir, g_free);
-  g_clear_pointer (&self->deploy_dir, g_free);
-  g_clear_pointer (&self->platform, g_free);
-  g_clear_pointer (&self->sdk, g_free);
-  g_clear_pointer (&self->program_paths_cache, g_hash_table_unref);
+  dzl_clear_pointer (&self->triplet, ide_triplet_unref);
+  dzl_clear_pointer (&self->branch, g_free);
+  dzl_clear_pointer (&self->runtime_dir, g_free);
+  dzl_clear_pointer (&self->deploy_dir, g_free);
+  dzl_clear_pointer (&self->platform, g_free);
+  dzl_clear_pointer (&self->sdk, g_free);
+  dzl_clear_pointer (&self->program_paths_cache, g_hash_table_unref);
   g_clear_object (&self->deploy_dir_files);
 
   G_OBJECT_CLASS (gbp_flatpak_runtime_parent_class)->finalize (object);
@@ -803,7 +803,6 @@ gbp_flatpak_runtime_new (IdeContext           *context,
   g_autofree gchar *id = NULL;
   g_autofree gchar *display_name = NULL;
   g_autofree gchar *triplet = NULL;
-  g_autoptr(FlatpakRef) sdk_ref = NULL;
   g_autoptr(IdeTriplet) triplet_object = NULL;
   const gchar *name;
   const gchar *arch;
