@@ -100,7 +100,6 @@ gbp_gdb_debugger_translate_path (GbpGdbDebugger *self,
                                  const gchar    *path)
 {
   g_autoptr(GFile) file = NULL;
-  g_autoptr(GFile) result = NULL;
   IdeRuntime *runtime = NULL;
   IdeRunner *runner;
 
@@ -249,7 +248,7 @@ gbp_gdb_debugger_cache_register_names (GbpGdbDebugger           *self,
                                  g_strdup (iter->variant.cstring));
         }
 
-      g_clear_pointer (&self->register_names, g_hash_table_unref);
+      dzl_clear_pointer (&self->register_names, g_hash_table_unref);
       self->register_names = g_steal_pointer (&hash);
     }
 }
@@ -1084,7 +1083,7 @@ gbp_gdb_debugger_reload_breakpoints_cb (GObject      *object,
     }
 
 cleanup:
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 /*
@@ -1167,7 +1166,7 @@ gbp_gdb_debugger_insert_breakpoint_cb (GObject      *object,
   if (output == NULL || gbp_gdb_debugger_unwrap (output, &error))
     {
       ide_task_return_error (task, g_steal_pointer (&error));
-      g_clear_pointer (&output, gdbwire_mi_output_free);
+      dzl_clear_pointer (&output, gdbwire_mi_output_free);
       return;
     }
 
@@ -1320,7 +1319,7 @@ gbp_gdb_debugger_remove_breakpoint_cb (GObject      *object,
       ide_task_return_boolean (task, TRUE);
     }
 
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 static void
@@ -1400,7 +1399,7 @@ gbp_gdb_debugger_list_register_names_cb (GObject      *object,
   gbp_gdb_debugger_cache_register_names (self, output);
 
 cleanup:
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 static void
@@ -1424,7 +1423,7 @@ gbp_gdb_debugger_move_cb (GObject      *object,
   else
     ide_task_return_boolean (task, TRUE);
 
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 static void
@@ -1600,7 +1599,7 @@ gbp_gdb_debugger_list_frames_cb (GObject      *object,
   ide_task_return_pointer (task, g_steal_pointer (&ar), (GDestroyNotify)g_ptr_array_unref);
 
 cleanup:
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 static void
@@ -1669,7 +1668,7 @@ gbp_gdb_debugger_interrupt_cb (GObject      *object,
   else
     ide_task_return_boolean (task, TRUE);
 
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 static void
@@ -1734,7 +1733,7 @@ gbp_gdb_debugger_send_signal_cb (GObject      *object,
   else
     ide_task_return_boolean (task, TRUE);
 
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 
@@ -1800,7 +1799,7 @@ gbp_gdb_debugger_modify_breakpoint_cb (GObject      *object,
 
   gbp_gdb_debugger_reload_breakpoints (self);
 
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 static void
@@ -1944,7 +1943,7 @@ gbp_gdb_debugger_list_locals_cb (GObject      *object,
   ide_task_return_pointer (task, g_steal_pointer (&ar), (GDestroyNotify)g_ptr_array_unref);
 
 cleanup:
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 static void
@@ -2076,7 +2075,7 @@ gbp_gdb_debugger_list_params_cb (GObject      *object,
   ide_task_return_pointer (task, g_steal_pointer (&ar), (GDestroyNotify)g_ptr_array_unref);
 
 cleanup:
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 static void
@@ -2196,7 +2195,7 @@ gbp_gdb_debugger_list_registers_cb (GObject      *object,
   ide_task_return_pointer (task, g_steal_pointer (&ar), (GDestroyNotify)g_ptr_array_unref);
 
 cleanup:
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 static void
@@ -2308,7 +2307,7 @@ gbp_gdb_debugger_disassemble_cb (GObject      *object,
   ide_task_return_pointer (task, g_steal_pointer (&ar), (GDestroyNotify)g_ptr_array_unref);
 
 cleanup:
-  g_clear_pointer (&output, gdbwire_mi_output_free);
+  dzl_clear_pointer (&output, gdbwire_mi_output_free);
 }
 
 static void
@@ -2386,7 +2385,7 @@ static void
 gbp_gdb_debugger_prepare (IdeDebugger *debugger,
                           IdeRunner   *runner)
 {
-  static gchar *prepend_argv[] = { "gdb", "--interpreter=mi2", "--args" };
+  static const gchar *prepend_argv[] = { "gdb", "--interpreter=mi2", "--args" };
   GbpGdbDebugger *self = (GbpGdbDebugger *)debugger;
   int tty_fd;
 
@@ -2497,9 +2496,9 @@ gbp_gdb_debugger_finalize (GObject *object)
 
   g_clear_object (&self->io_stream);
   g_clear_object (&self->read_cancellable);
-  g_clear_pointer (&self->parser, gdbwire_mi_parser_destroy);
-  g_clear_pointer (&self->read_buffer, g_free);
-  g_clear_pointer (&self->register_names, g_hash_table_unref);
+  dzl_clear_pointer (&self->parser, gdbwire_mi_parser_destroy);
+  dzl_clear_pointer (&self->read_buffer, g_free);
+  dzl_clear_pointer (&self->register_names, g_hash_table_unref);
   g_queue_clear (&self->cmdqueue);
 
   G_OBJECT_CLASS (gbp_gdb_debugger_parent_class)->finalize (object);
@@ -2638,7 +2637,6 @@ gbp_gdb_debugger_connect (GbpGdbDebugger *self,
                           GIOStream      *io_stream,
                           GCancellable   *cancellable)
 {
-  g_autoptr(GError) error = NULL;
   GInputStream *stream;
 
   g_return_if_fail (GBP_IS_GDB_DEBUGGER (self));
