@@ -31,6 +31,7 @@ struct _IdeGitCloneWidget
   GtkBin                parent_instance;
 
   gchar                *child_name;
+  gchar                *branch_name;
 
   DzlFileChooserEntry  *clone_location_entry;
   GtkEntry             *clone_uri_entry;
@@ -63,7 +64,7 @@ clone_request_free (gpointer data)
 
   if (req != NULL)
     {
-      g_clear_pointer (&req->uri, ide_vcs_uri_unref);
+      dzl_clear_pointer (&req->uri, ide_vcs_uri_unref);
       g_clear_object (&req->location);
       g_clear_object (&req->project_file);
       g_slice_free (CloneRequest, req);
@@ -100,7 +101,7 @@ ide_git_clone_widget_uri_changed (IdeGitCloneWidget *self,
   g_assert (IDE_IS_GIT_CLONE_WIDGET (self));
   g_assert (GTK_IS_ENTRY (entry));
 
-  g_clear_pointer (&self->child_name, g_free);
+  dzl_clear_pointer (&self->child_name, g_free);
 
   text = gtk_entry_get_text (entry);
   str = g_string_new (NULL);
@@ -181,12 +182,65 @@ ide_git_clone_widget_uri_changed (IdeGitCloneWidget *self,
     }
 }
 
+static void
+branch_popover_activate_cb (IdeGitCloneWidget *self,
+                            const gchar       *text,
+                            DzlSimplePopover  *popover)
+{
+  g_assert (IDE_IS_GIT_CLONE_WIDGET (self));
+  g_assert (DZL_IS_SIMPLE_POPOVER (popover));
+
+  if (text == NULL || *text == 0)
+    text = "master";
+
+  g_free (self->branch_name);
+  self->branch_name = g_strdup (text);
+}
+
+static void
+ide_git_clone_widget_icon_press_cb (IdeGitCloneWidget    *self,
+                                    GtkEntryIconPosition  pos,
+                                    const GdkEvent       *event,
+                                    GtkEntry             *entry)
+{
+  GtkPopover *popover;
+
+  g_assert (IDE_IS_GIT_CLONE_WIDGET (self));
+  g_assert (event != NULL);
+  g_assert (GTK_IS_ENTRY (entry));
+
+  if (pos != GTK_ENTRY_ICON_PRIMARY)
+    return;
+
+  popover = g_object_new (DZL_TYPE_SIMPLE_POPOVER,
+                          "button-text", _("Apply"),
+                          "ready", TRUE,
+                          "title", _("Remote Branch to Clone"),
+                          "text", self->branch_name,
+                          "relative-to", entry,
+                          "position", GTK_POS_LEFT,
+                          NULL);
+
+  g_signal_connect_object (popover,
+                           "activate",
+                           G_CALLBACK (branch_popover_activate_cb),
+                           self,
+                           G_CONNECT_SWAPPED);
+
+  g_signal_connect (popover,
+                    "closed",
+                    G_CALLBACK (gtk_widget_destroy),
+                    NULL);
+
+  gtk_popover_popup (popover);
+}
+
 static void
 ide_git_clone_widget_finalize (GObject *object)
 {
   IdeGitCloneWidget *self = (IdeGitCloneWidget *)object;
 
-  g_clear_pointer (&self->child_name, g_free);
+  dzl_clear_pointer (&self->child_name, g_free);
 
   G_OBJECT_CLASS (ide_git_clone_widget_parent_class)->finalize (object);
 }
@@ -241,6 +295,8 @@ ide_git_clone_widget_init (IdeGitCloneWidget *self)
 {
   g_autoptr(GFile) projects_dir = NULL;
 
+  self->branch_name = g_strdup ("master");
+
   gtk_widget_init_template (GTK_WIDGET (self));
 
   projects_dir = ide_application_get_projects_directory (IDE_APPLICATION_DEFAULT);
@@ -253,6 +309,12 @@ ide_git_clone_widget_init (IdeGitCloneWidget *self)
                            G_CALLBACK (ide_git_clone_widget_uri_changed),
                            self,
                            G_CONNECT_SWAPPED);
+
+  g_signal_connect_object (self->clone_uri_entry,
+                           "icon-press",
+                           G_CALLBACK (ide_git_clone_widget_icon_press_cb),
+                           self,
+                           G_CONNECT_SWAPPED);
 }
 
 static gboolean
@@ -359,9 +421,9 @@ ide_git_clone_widget_worker (IdeTask      *task,
 
   clone_options = ggit_clone_options_new ();
   ggit_clone_options_set_is_bare (clone_options, FALSE);
-  ggit_clone_options_set_checkout_branch (clone_options, "master");
+  ggit_clone_options_set_checkout_branch (clone_options, self->branch_name);
   ggit_clone_options_set_fetch_options (clone_options, fetch_options);
-  g_clear_pointer (&fetch_options, ggit_fetch_options_free);
+  dzl_clear_pointer (&fetch_options, ggit_fetch_options_free);
 
   uristr = ide_vcs_uri_to_string (req->uri);
 
@@ -438,12 +500,6 @@ ide_git_clone_widget_clone_async (IdeGitCloneWidget   *self,
       return;
     }
 
-  if (g_strcmp0 ("ssh", ide_vcs_uri_get_scheme (uri)) == 0)
-    {
-      if (ide_vcs_uri_get_user (uri) == NULL)
-        ide_vcs_uri_set_user (uri, g_get_user_name ());
-    }
-
   if (self->child_name)
     {
       g_autoptr(GFile) child = g_file_get_child (location, self->child_name);
