@@ -170,7 +170,6 @@ ide_git_vcs_discover (IdeGitVcs  *self,
 {
   g_autofree gchar *name = NULL;
   g_autoptr(GFile) parent = NULL;
-  g_autoptr(GFile) git = NULL;
   g_autoptr(GFile) child = NULL;
 
   g_assert (IDE_IS_GIT_VCS (self));
@@ -797,7 +796,7 @@ ide_git_vcs_finalize (GObject *object)
   IDE_ENTRY;
 
   g_mutex_clear (&self->repository_mutex);
-  g_clear_pointer (&self->worktree_branch, g_free);
+  dzl_clear_pointer (&self->worktree_branch, g_free);
 
   G_OBJECT_CLASS (ide_git_vcs_parent_class)->finalize (object);
 
