@@ -1,6 +1,6 @@
 /* gbp-meson-test.c
  *
- * Copyright © 2017 Christian Hergert <chergert@redhat.com>
+ * Copyright 2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,8 +47,8 @@ gbp_meson_test_finalize (GObject *object)
 {
   GbpMesonTest *self = (GbpMesonTest *)object;
 
-  g_clear_pointer (&self->command, g_strfreev);
-  g_clear_pointer (&self->environ, g_strfreev);
+  dzl_clear_pointer (&self->command, g_strfreev);
+  dzl_clear_pointer (&self->environ, g_strfreev);
   g_clear_object (&self->workdir);
 
   G_OBJECT_CLASS (gbp_meson_test_parent_class)->finalize (object);
