@@ -1,6 +1,6 @@
 /* gbp-spell-navigator.c
  *
- * Copyright © 2016 Sebastien Lafargue <slafargue@gnome.org>
+ * Copyright 2016 Sebastien Lafargue <slafargue@gnome.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -285,7 +285,7 @@ gbp_spell_navigator_dispose (GObject *object)
   GbpSpellNavigator *self = (GbpSpellNavigator *)object;
 
   g_clear_object (&self->view);
-  g_clear_pointer (&self->words_count, g_hash_table_unref);
+  dzl_clear_pointer (&self->words_count, g_hash_table_unref);
 
   if (self->buffer != NULL)
     {
