@@ -707,7 +707,7 @@ gbp_spell_widget__language_notify_cb (GbpSpellWidget *self,
           gtk_list_box_select_row (self->suggestions_box, row);
         }
 
-      g_clear_pointer (&self->words_array, g_ptr_array_unref);
+      dzl_clear_pointer (&self->words_array, g_ptr_array_unref);
 
       if (current_language == NULL)
         {
@@ -813,7 +813,7 @@ gbp_spell_widget__dict__loaded_cb (GbpSpellWidget *self,
 
   self->words_array = gbp_spell_dict_get_words (self->dict);
   dict_fill_listbox (self, self->words_array);
-  g_clear_pointer (&self->words_array, g_ptr_array_unref);
+  dzl_clear_pointer (&self->words_array, g_ptr_array_unref);
 }
 
 static void
@@ -942,16 +942,18 @@ gbp_spell_widget_unbind_addin (GbpSpellWidget *self,
 {
   g_assert (GBP_IS_SPELL_WIDGET (self));
   g_assert (DZL_IS_SIGNAL_GROUP (editor_view_addin_signals));
-  g_assert (self->editor_view_addin != NULL);
 
-  gbp_spell_editor_view_addin_end_checking (self->editor_view_addin);
-  gbp_spell_dict_set_checker (self->dict, NULL);
-  self->language = NULL;
-  gspell_language_chooser_set_language (GSPELL_LANGUAGE_CHOOSER (self->language_chooser_button), NULL);
+  if (self->editor_view_addin != NULL)
+    {
+      gbp_spell_editor_view_addin_end_checking (self->editor_view_addin);
+      gbp_spell_dict_set_checker (self->dict, NULL);
+      self->language = NULL;
+      gspell_language_chooser_set_language (GSPELL_LANGUAGE_CHOOSER (self->language_chooser_button), NULL);
 
-  g_clear_object (&self->editor_view_addin);
+      g_clear_object (&self->editor_view_addin);
 
-  _gbp_spell_widget_update_actions (self);
+      _gbp_spell_widget_update_actions (self);
+    }
 }
 
 static void
@@ -974,7 +976,7 @@ gbp_spell_widget_destroy (GtkWidget *widget)
   g_clear_object (&self->editor_view_addin);
   g_clear_object (&self->editor_view_addin_signals);
   g_clear_object (&self->dict);
-  g_clear_pointer (&self->words_array, g_ptr_array_unref);
+  dzl_clear_pointer (&self->words_array, g_ptr_array_unref);
 
   GTK_WIDGET_CLASS (gbp_spell_widget_parent_class)->destroy (widget);
 }
