@@ -39,7 +39,7 @@ GbpSysrootRuntime *
 gbp_sysroot_runtime_new (IdeContext  *context,
                          const gchar *sysroot_id)
 {
-  g_autoptr(IdeRuntime) runtime = NULL;
+  g_autoptr(GbpSysrootRuntime) runtime = NULL;
   g_autofree gchar *built_id = NULL;
 
   g_return_val_if_fail (IDE_IS_CONTEXT (context), NULL);
@@ -96,7 +96,6 @@ gbp_sysroot_runtime_create_launcher (IdeRuntime  *runtime,
       g_autofree gchar *pkgconfig_dirs = NULL;
       g_autofree gchar *cflags = NULL;
       g_autofree gchar *ldflags = NULL;
-      g_auto(GStrv) path_parts = NULL;
       const gchar *previous_env = NULL;
       const gchar *sysroot_id = NULL;
 
