@@ -64,6 +64,7 @@ static const gchar *exclude_dirs[] = {
   ".flatpak-builder",
   ".git",
   ".svn",
+  "node_modules",
 };
 
 /* This is an optimization to avoid reading files in from disk that
@@ -71,6 +72,8 @@ static const gchar *exclude_dirs[] = {
  * for that information.
  */
 static const gchar *exclude_files[] = {
+  "*~",
+  "*.swp",
   "*.m4",
   "*.po",
   "*.min.js.*",
@@ -92,7 +95,7 @@ result_info_free (gpointer data)
   ResultInfo *info = data;
 
   g_clear_object (&info->self);
-  g_clear_pointer (&info->items, g_ptr_array_unref);
+  dzl_clear_pointer (&info->items, g_ptr_array_unref);
   g_slice_free (ResultInfo, info);
 }
 
