@@ -94,9 +94,9 @@ ide_xml_position_free (IdeXmlPosition *self)
   if (self->analysis != NULL)
     ide_xml_analysis_unref (self->analysis);
 
-  g_clear_pointer (&self->prefix, g_free);
-  g_clear_pointer (&self->detail_name, g_free);
-  g_clear_pointer (&self->detail_value, g_free);
+  dzl_clear_pointer (&self->prefix, g_free);
+  dzl_clear_pointer (&self->detail_name, g_free);
+  dzl_clear_pointer (&self->detail_value, g_free);
 
   g_clear_object (&self->node);
   g_clear_object (&self->child_node);
@@ -110,7 +110,7 @@ IdeXmlPosition *
 ide_xml_position_ref (IdeXmlPosition *self)
 {
   g_return_val_if_fail (self, NULL);
-  g_return_val_if_fail (self->ref_count, NULL);
+  g_return_val_if_fail (self->ref_count > 0, NULL);
 
   g_atomic_int_inc (&self->ref_count);
 
@@ -121,7 +121,7 @@ void
 ide_xml_position_unref (IdeXmlPosition *self)
 {
   g_return_if_fail (self);
-  g_return_if_fail (self->ref_count);
+  g_return_if_fail (self->ref_count > 0);
 
   if (g_atomic_int_dec_and_test (&self->ref_count))
     ide_xml_position_free (self);
@@ -205,7 +205,7 @@ ide_xml_position_kind_get_str (IdeXmlPositionKind kind)
   return kind_str;
 }
 
-const gchar *
+static const gchar *
 ide_xml_position_detail_get_str (IdeXmlPositionDetail detail)
 {
   const gchar *detail_str = NULL;
