@@ -1,6 +1,6 @@
 /* ide-xml-stack.c
  *
- * Copyright © 2017 Sebastien Lafargue <slafargue@gnome.org>
+ * Copyright 2017 Sebastien Lafargue <slafargue@gnome.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -156,7 +156,7 @@ ide_xml_stack_finalize (GObject *object)
 {
   IdeXmlStack *self = (IdeXmlStack *)object;
 
-  g_clear_pointer (&self->array, g_array_unref);
+  dzl_clear_pointer (&self->array, g_array_unref);
 
   G_OBJECT_CLASS (ide_xml_stack_parent_class)->finalize (object);
 }
