@@ -1,6 +1,6 @@
 /* ide-xml-symbol-node.c
  *
- * Copyright © 2017 Sébastien Lafargue <slafargue@gnome.org>
+ * Copyright 2017 Sébastien Lafargue <slafargue@gnome.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -78,7 +78,7 @@ ide_xml_symbol_node_get_location_async (IdeSymbolNode       *node,
                                         gpointer             user_data)
 {
   IdeXmlSymbolNode *self = (IdeXmlSymbolNode *)node;
-  g_autoptr(GTask) task = NULL;
+  g_autoptr(IdeTask) task = NULL;
   IdeContext *context;
   g_autoptr(IdeFile) ifile = NULL;
   IdeSourceLocation *ret;
@@ -87,8 +87,8 @@ ide_xml_symbol_node_get_location_async (IdeSymbolNode       *node,
   g_return_if_fail (G_IS_FILE (self->file));
   g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
 
-  task = g_task_new (self, cancellable, callback, user_data);
-  g_task_set_source_tag (task, ide_xml_symbol_node_get_location_async);
+  task = ide_task_new (self, cancellable, callback, user_data);
+  ide_task_set_source_tag (task, ide_xml_symbol_node_get_location_async);
 
   context = ide_object_get_context (IDE_OBJECT (self));
   ifile = ide_file_new (context, self->file);
@@ -98,7 +98,7 @@ ide_xml_symbol_node_get_location_async (IdeSymbolNode       *node,
                                  self->start_tag.start_line_offset - 1,
                                  0);
 
-  g_task_return_pointer (task, ret, (GDestroyNotify)ide_source_location_unref);
+  ide_task_return_pointer (task, ret, (GDestroyNotify)ide_source_location_unref);
 }
 
 static IdeSourceLocation *
@@ -107,9 +107,9 @@ ide_xml_symbol_node_get_location_finish (IdeSymbolNode  *node,
                                          GError        **error)
 {
   g_return_val_if_fail (IDE_IS_XML_SYMBOL_NODE (node), NULL);
-  g_return_val_if_fail (G_IS_TASK (result), NULL);
+  g_return_val_if_fail (IDE_IS_TASK (result), NULL);
 
-  return g_task_propagate_pointer (G_TASK (result), error);
+  return ide_task_propagate_pointer (IDE_TASK (result), error);
 }
 
 static void
@@ -117,11 +117,11 @@ ide_xml_symbol_node_finalize (GObject *object)
 {
   IdeXmlSymbolNode *self = (IdeXmlSymbolNode *)object;
 
-  g_clear_pointer (&self->children, g_array_unref);
-  g_clear_pointer (&self->attributes, g_array_unref);
+  dzl_clear_pointer (&self->children, g_array_unref);
+  dzl_clear_pointer (&self->attributes, g_array_unref);
 
-  g_clear_pointer (&self->element_name, g_free);
-  g_clear_pointer (&self->value, g_free);
+  dzl_clear_pointer (&self->element_name, g_free);
+  dzl_clear_pointer (&self->value, g_free);
 
   g_clear_object (&self->file);
   g_clear_object (&self->parent);
@@ -548,7 +548,7 @@ ide_xml_symbol_node_set_element_name (IdeXmlSymbolNode *self,
   g_return_if_fail (IDE_IS_XML_SYMBOL_NODE (self));
   g_return_if_fail (!dzl_str_empty0 (element_name));
 
-  g_clear_pointer (&self->element_name, g_free);
+  dzl_clear_pointer (&self->element_name, g_free);
 
   if (element_name != NULL)
     self->element_name = g_strdup (element_name);
@@ -585,7 +585,7 @@ ide_xml_symbol_node_set_value (IdeXmlSymbolNode *self,
 {
   g_return_if_fail (IDE_IS_XML_SYMBOL_NODE (self));
 
-  g_clear_pointer (&self->value, g_free);
+  dzl_clear_pointer (&self->value, g_free);
 
   if (value != NULL)
     self->value = g_strdup (value);
@@ -668,7 +668,7 @@ ide_xml_symbol_node_set_attributes (IdeXmlSymbolNode  *self,
 
   g_return_if_fail (IDE_IS_XML_SYMBOL_NODE (self));
 
-  g_clear_pointer (&self->attributes, g_array_unref);
+  dzl_clear_pointer (&self->attributes, g_array_unref);
   if (attributes == NULL)
     return;
 
